import Vue from 'vue'
import Vuex from 'vuex'

Vue.use(Vuex)

export default new Vuex.Store({
    state: {
        userdata: {
            name: null
        },
        appReady: false,
        playerActive: false,
        playerUrl: ""
    },
    mutations: {
        storeUserData(state, username) {
            state.userdata.name = username;
        },
        setAppReady(state) {
            state.appReady = true;
        },
        openPlayer(state, spotify_id) {
            const id_parts = spotify_id.split(":");
            state.playerUrl = `https://open.spotify.com/embed/${id_parts[1]}/${id_parts[2]}`;
            state.playerActive = true;
        },
        closePlayer(state) {
            state.playerActive = false;
        },
        logoutReset(state) {
            state.userdata.name = null;
            state.playerUrl = "";
            state.playerActive = false;
        }
    },
    actions: {
        storeUserData({commit}, username) {
            commit('storeUserData', username);
        },
        setAppReady({commit}) {
            commit('setAppReady');
        },
        openPlayer({commit}, spotify_id) {
            commit('openPlayer', spotify_id);
        },
        closePlayer({commit}) {
            commit('closePlayer');
        },
        logoutReset({commit}) {
            commit('logoutReset');
        }
    },
    modules: {},
    getters: {
        isLoggedIn(state) {
            return !!state.userdata.name;
        }
    }
})
